from dash import html
from dash import dcc
import dash
import numpy as np
import pandas as pd

from dash.dependencies import Input, Output
import plotly.express as px

external_stylesheets = ['https://codepen.io/chriddyp/pen/bWLwgP.css']

app = dash.Dash(__name__, external_stylesheets=external_stylesheets)

dfS = px.data.gapminder().query("country=='Canada'")

app.layout = html.Div([
    html.Div(
        dcc.Slider(
        id='year-slider',
        min=dfS['year'].min(),
        max=dfS['year'].max(),
        value=dfS['year'].min(),
        marks={str(year): str(year) for year in dfS['year'].unique()}
        )
    ),
    html.Div(
        dcc.Graph(id='g1', config={'displayModeBar': False}),
        className='four columns'
    ),
    html.Div(
        dcc.Graph(id='g2', config={'displayModeBar': False}),
        className='four columns'
    ),
    html.Div(
        dcc.Graph(id='g3', config={'displayModeBar': False}),
        className='four columns'
    )
], className='row')

def linePlot():
    df = px.data.gapminder().query("country=='Canada'")
    fig = px.line(df, x="year", y="lifeExp", title='Life expectancy in Canada')
    return fig

def barChart(year):
    data_canada = px.data.gapminder().query("country == 'Canada'")
    filtered_df = data_canada[data_canada.year == year]
    fig = px.bar(filtered_df, x='year', y='pop')
    return fig

def scatterPlot():
    fig = px.scatter(x=[0, 1, 2, 3, 4], y=[0, 1, 4, 9, 16])
    return fig


@app.callback(
    Output('g1', 'figure'),
    Output('g2', 'figure'),
    Output('g3', 'figure'),
    Input('year-slider', 'value')

)
def callback(year):

    return [linePlot(),
            barChart(year),
            scatterPlot()]


if __name__ == '__main__':
    app.run_server(debug=True)
