from dash import html
from dash import dcc
import dash
import numpy as np
import pandas as pd

from dash.dependencies import Input, Output
import plotly.express as px

external_stylesheets = ['https://codepen.io/chriddyp/pen/bWLwgP.css']

app = dash.Dash(__name__, external_stylesheets=external_stylesheets)

dfS = px.data.gapminder().query("country=='Canada'")

app.layout = html.Div([
    html.Div(
        dcc.Slider(
        id='year-slider',
        min=dfS['year'].min(),
        max=dfS['year'].max(),
        value=dfS['year'].min(),
        marks={str(year): str(year) for year in dfS['year'].unique()}
        )
    ),
    html.Div(
        dcc.Graph(id='g1', config={'displayModeBar': False}),
        className='four columns'
    )
], className='row')

@app.callback(
    Output('g1', 'figure'),
    Input('year-slider', 'value')

)
def callback(year):
    fig = px.bar(dfS, x='year', y='pop')
    return fig


if __name__ == '__main__':
    app.run_server(debug=True)
